@@ -32,11 +32,16 @@
   maybe_tsibble <- n_keys(x) > 1 && !all(is.element(key(x), new_key))
   if (not_tsibble || maybe_tsibble) {
     as_tibble(res)
-  } else {
+  } else if (index2_var(x) %in% names(res)) {
     build_tsibble(
       res, key = !! new_key, index = !! index(x), index2 = !! index2(x),
       interval = is_regular(x), ordered = is_ordered(x), validate = FALSE
     )
+  } else { # index2 not there
+    build_tsibble(
+      res, key = !! new_key, index = !! index(x), interval = is_regular(x),
+      ordered = is_ordered(x), validate = FALSE
+    )
   }
 }
 
