@@ -7,6 +7,7 @@ knitr::opts_chunk$set(
 options(tibble.print_min = 5)
 
 ## ----load----------------------------------------------------------------
+library(dplyr)
 library(tsibble)
 library(lubridate)
 
@@ -28,12 +29,12 @@ tsibble(time = x + hours(c(0, 3, 6, 9)) , index = time)
 tsbl1 <- tsibble(
   time = make_datetime(2018) + hours(0:3),
   station = "A",
-  index = time, key = id(station)
+  index = time, key = station
 ) %>% print()
 tsbl2 <- tsibble(
   time = make_datetime(2018) + minutes(seq(0, 90, by = 30)),
   station = "B",
-  index = time, key = id(station)
+  index = time, key = station
 ) %>% print()
 rbind(tsbl1, tsbl2)
 
@@ -43,10 +44,10 @@ tbl <- tibble(
   time = c(x, x + minutes(15)),
   station = rep(c("A", "B"), 2)
 )
-as_tsibble(tbl, index = time, key = id(station))
+as_tsibble(tbl, index = time, key = station)
 
 ## ------------------------------------------------------------------------
 tbl %>% 
   mutate(time = floor_date(time, unit = "15 mins")) %>% 
-  as_tsibble(index = time, key = id(station))
+  as_tsibble(index = time, key = station)
 
